@@ -24,7 +24,7 @@ class Querier:
             async with aiohttp.ClientSession() as session:
                 response = await session.get(*args, **kwargs)
                 if int(response.status) != 200:
-                    print(f"SDC Произошла ошибка: {response.status} {response.json()}")
+                    print(f"SDC: Произошла ошибка: {response.status} {await response.json()}")
         finally:
             asyncio.get_event_loop().create_task(self._wait_ratelimit())
 
@@ -38,7 +38,7 @@ class Querier:
             async with aiohttp.ClientSession() as session:
                 response = await session.post(*args, **kwargs)
                 if int(response.status) != 200:
-                    print(f"SDC Произошла ошибка: {response.status} {response.json()}")
+                    print(f"SDC: Произошла ошибка: {response.status} {response.json()}")
         finally:
             asyncio.get_event_loop().create_task(self._wait_ratelimit("bots"))
 
